rai\_toolbox.mushin.HydraDDP
============================

.. currentmodule:: rai_toolbox.mushin

.. autoclass:: HydraDDP

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HydraDDP.__init__
